 src/EntityToJsonApi.php                              |  6 +++---
 src/ResourceType/ResourceType.php                    | 10 ++++++----
 src/ResourceType/ResourceTypeRepository.php          |  4 ++--
 src/ResourceType/ResourceTypeRepositoryInterface.php |  8 +++++---
 src/Routing/Routes.php                               |  8 ++++----
 5 files changed, 20 insertions(+), 16 deletions(-)

diff --git a/src/EntityToJsonApi.php b/src/EntityToJsonApi.php
index 30bcd3f..99ba536 100644
--- a/src/EntityToJsonApi.php
+++ b/src/EntityToJsonApi.php
@@ -98,13 +98,13 @@ class EntityToJsonApi {
    */
   protected function calculateContext(EntityInterface $entity) {
     // TODO: Supporting includes requires adding the 'include' query string.
-    $path_prefix = $this->resourceTypeRepository->getPathPrefix();
+    $path_prefix = $this->resourceTypeRepository->getPrefixPathSegment();
     $resource_type = $this->resourceTypeRepository->get(
       $entity->getEntityTypeId(),
       $entity->bundle()
     );
-    $resource_path = $resource_type->getPath();
-    $path = sprintf('/%s/%s/%s', $path_prefix, $resource_path, $entity->uuid());
+    $resource_path = $resource_type->getPathSegments();
+    $path = sprintf('%s%s/%s', $path_prefix, $resource_path, $entity->uuid());
     $request = Request::create($path, 'GET');
     return [
       'account' => $this->currentUser,
diff --git a/src/ResourceType/ResourceType.php b/src/ResourceType/ResourceType.php
index f2257dd..ff06954 100644
--- a/src/ResourceType/ResourceType.php
+++ b/src/ResourceType/ResourceType.php
@@ -244,13 +244,15 @@ class ResourceType {
   }
 
   /**
-   * Get the resource path.
+   * Gets the resource type path segments.
    *
    * @return string
-   *   The path to access this resource type. Defaults to entity_type_id/bundle.
+   *   The path segments to access this resource type, without path prefix.
+   *
+   * @see \Drupal\jsonapi\ResourceType\ResourceTypeRepositoryInterface::getPrefixPathSegment()
    */
-  public function getPath() {
-    return sprintf('%s/%s', $this->getEntityTypeId(), $this->getBundle());
+  public function getPathSegments() {
+    return sprintf('/%s/%s', $this->getEntityTypeId(), $this->getBundle());
   }
 
 }
diff --git a/src/ResourceType/ResourceTypeRepository.php b/src/ResourceType/ResourceTypeRepository.php
index c536925..7ead907 100644
--- a/src/ResourceType/ResourceTypeRepository.php
+++ b/src/ResourceType/ResourceTypeRepository.php
@@ -76,8 +76,8 @@ class ResourceTypeRepository implements ResourceTypeRepositoryInterface {
   /**
    * {@inheritdoc}
    */
-  public function getPathPrefix() {
-    return 'jsonapi';
+  public function getPrefixPathSegment() {
+    return '/jsonapi';
   }
 
   // @codingStandardsIgnoreStart
diff --git a/src/Routing/Routes.php b/src/Routing/Routes.php
index 66d7537..e8d435f 100644
--- a/src/Routing/Routes.php
+++ b/src/Routing/Routes.php
@@ -80,7 +80,7 @@ class Routes implements ContainerInjectionInterface {
   public function entryPoint() {
     $collection = new RouteCollection();
 
-    $path_prefix = $this->resourceTypeRepository->getPathPrefix();
+    $path_prefix = $this->resourceTypeRepository->getPrefixPathSegment();
     $route_collection = (new Route('/' . $path_prefix, [
       RouteObjectInterface::CONTROLLER_NAME => '\Drupal\jsonapi\Controller\EntryPoint::index',
     ]))
@@ -105,9 +105,9 @@ class Routes implements ContainerInjectionInterface {
         continue;
       }
 
-      $path_prefix = $this->resourceTypeRepository->getPathPrefix();
-      $resource_path = $resource_type->getPath();
-      $route_base_path = sprintf('/%s/%s', $path_prefix, $resource_path);
+      $path_prefix = $this->resourceTypeRepository->getPrefixPathSegment();
+      $resource_path = $resource_type->getPathSegments();
+      $route_base_path = sprintf('%s%s', $path_prefix, $resource_path);
       $build_route_name = function ($key) use ($resource_type) {
         return sprintf('jsonapi.%s.%s', $resource_type->getTypeName(), $key);
       };

diff --git a/src/ResourceType/ResourceTypeRepositoryInterface.php b/src/ResourceType/ResourceTypeRepositoryInterface.php
index b44f3d6..7d33016 100644
--- a/src/ResourceType/ResourceTypeRepositoryInterface.php
+++ b/src/ResourceType/ResourceTypeRepositoryInterface.php
@@ -42,11 +42,13 @@ interface ResourceTypeRepositoryInterface {
   public function getByTypeName($type_name);
 
   /**
    * Gets the path prefix for routes managed by JSON API.
    *
    * @return string
-   *   The route prefix in the JSON API route paths.
+   *   The prefix path segment in the JSON API route paths.
+   *
+   * @see \Drupal\jsonapi\ResourceType\ResourceType::getPathSegments()
    */
-  public function getPathPrefix();
+  public function getPrefixPathSegment();
 
 }
@@ -42,11 +42,13 @@ interface ResourceTypeRepositoryInterface {
 
   /**
-   * Gets the path prefix for routes managed by JSON API.
+   * Gets the JSON API route prefix path segment.
    *
    * @return string